@@ -5,11 +5,11 @@ extern crate agb;
 
 use agb::display;
 
-#[no_mangle]
-pub fn main() -> ! {
+#[agb::entry]
+fn main() -> ! {
     let mut gba = agb::Gba::new();
     let mut bitmap = gba.display.video.bitmap4();
-    let vblank = gba.display.vblank.get();
+    let vblank = agb::interrupt::VBlank::get();
 
     bitmap.set_palette_entry(1, 0x001F);
     bitmap.set_palette_entry(2, 0x03E0);
@@ -30,7 +30,7 @@ pub fn main() -> ! {
     let mut count = 0;
 
     loop {
-        vblank.wait_for_VBlank();
+        vblank.wait_for_vblank();
         count += 1;
         if count % 6 == 0 {
             bitmap.flip_page();
