@@ -3,7 +3,7 @@
 
 extern crate agb;
 use agb::{
-    display::{object::ObjectStandard, HEIGHT, WIDTH},
+    display::{background::Map, object::ObjectStandard, HEIGHT, WIDTH},
     input::Button,
 };
 use core::convert::TryInto;
@@ -35,8 +35,8 @@ fn frame_ranger(count: u32, start: u32, end: u32, delay: u32) -> u16 {
     (((count / delay) % (end + 1 - start)) + start) as u16
 }
 
-#[no_mangle]
-pub fn main() -> ! {
+#[agb::entry]
+fn main() -> ! {
     let map_as_grid: &[[u16; 32]; 32] = unsafe {
         (&MAP_MAP as *const [u16; 1024] as *const [[u16; 32]; 32])
             .as_ref()
@@ -45,21 +45,22 @@ pub fn main() -> ! {
 
     let mut gba = agb::Gba::new();
     let mut gfx = gba.display.video.tiled0();
-    let vblank = gba.display.vblank.get();
+    let vblank = agb::interrupt::VBlank::get();
     let mut input = agb::input::ButtonController::new();
 
-    gfx.set_sprite_palette_raw(&CHICKEN_PALETTE);
-    gfx.set_sprite_tilemap(&CHICKEN_TILES);
-
     gfx.set_background_palette_raw(&MAP_PALETTE);
     gfx.set_background_tilemap(0, &MAP_TILES);
 
-    let mut background = gfx.get_background().unwrap();
-    background.draw_full_map(&MAP_MAP, (32_u32, 32_u32).into(), 0);
+    let mut background = gfx.get_regular().unwrap();
+    background.set_map(Map::new(&MAP_MAP, (32_u32, 32_u32).into(), 0));
     background.show();
+    background.commit();
 
     let mut object = gba.display.object.get();
 
+    object.set_sprite_palette_raw(&CHICKEN_PALETTE);
+    object.set_sprite_tilemap(&CHICKEN_TILES);
+
     object.enable();
     let mut chicken = Character {
         object: object.get_object_standard(),
@@ -90,7 +91,7 @@ pub fn main() -> ! {
     let terminal_velocity = (1 << 8) / 2;
 
     loop {
-        vblank.wait_for_VBlank();
+        vblank.wait_for_vblank();
         frame_count += 1;
 
         input.update();
