@@ -4,8 +4,8 @@
 extern crate agb;
 use agb::{display, syscall};
 
-#[no_mangle]
-pub fn main() -> ! {
+#[agb::entry]
+fn main() -> ! {
     let mut gba = agb::Gba::new();
     let mut bitmap = gba.display.video.bitmap3();
 
