@@ -26,9 +26,9 @@ impl<const N: usize> Bitarray<N> {
 #[test_case]
 fn write_and_read(_gba: &mut crate::Gba) {
     let mut a: Bitarray<2> = Bitarray::new();
-    assert_eq!(a.get(55).unwrap(), false, "expect unset values to be false");
+    assert_eq!(a.get(55), Some(false), "expect unset values to be false");
     a.set(62, true);
-    assert_eq!(a.get(62).unwrap(), true, "expect set value to be true");
+    assert_eq!(a.get(62), Some(true), "expect set value to be true");
     assert_eq!(a.get(120), None, "expect out of range to give None");
 }
 
@@ -38,7 +38,7 @@ fn test_everything(_gba: &mut crate::Gba) {
         let mut a: Bitarray<2> = Bitarray::new();
         a.set(i, true);
         for j in 0..64 {
-            let expected = if i == j { true } else { false };
+            let expected = i == j;
             assert_eq!(
                 a.get(j).unwrap(),
                 expected,
