@@ -39,8 +39,9 @@ pub fn wait_for_interrupt() {
     }
 }
 
-#[allow(non_snake_case)]
-pub fn wait_for_VBlank() {
+/// The vblank interrupt handler [VBlank][crate::interrupt::VBlank] should be
+/// used instead of calling this function directly.
+pub fn wait_for_vblank() {
     unsafe {
         asm!(
             "swi 0x05",
